/**
 * Copyright 2013-2024 the original author or authors from the JHipster project.
 *
 * This file is part of the JHipster project, see https://www.jhipster.tech/
 * for more information.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export { formatComment };
/**
 * formats a comment
 * @param comment string.
 * @returns formatted comment string
 */
export default function formatComment(comment) {
    if (!comment) {
        return undefined;
    }
    const parts = comment.trim().split('\n');
    if (parts.length === 1 && parts[0].indexOf('*') !== 0) {
        return parts[0];
    }
    return parts.reduce((previousValue, currentValue) => {
        // newlines in the middle of the comment should stay to achieve:
        // multiline comments entered by user drive unchanged from JDL
        // studio to generated domain class
        let delimiter = '';
        if (previousValue !== '') {
            delimiter = '\\n';
        }
        return previousValue.concat(delimiter, currentValue.trim().replace(/[*]*\s*/, ''));
    }, '');
}
