/**
 * Copyright 2013-2024 the original author or authors from the JHipster project.
 *
 * This file is part of the JHipster project, see https://www.jhipster.tech/
 * for more information.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export type JDLOptionParams = {
    name: string;
    entityNames?: Set<string> | string[];
    excludedNames?: Set<string> | string[];
};
export default class AbstractJDLOption {
    name: string;
    entityNames: Set<string>;
    excludedNames: Set<string>;
    constructor(args: JDLOptionParams);
    addEntityName(entityName: string): false | Set<string>;
    addEntitiesFromAnotherOption(option?: AbstractJDLOption): boolean;
    excludeEntityName(entityName: string): void;
    getType(): string;
    setEntityNames(newEntityNames: Iterable<string>): void;
    /**
     * Resolves the option's list of entity names (without '*' and taking into account the excluded names).
     * @param entityNames all the entity names declared in a JDL Object.
     * @returns the resolved list.
     */
    resolveEntityNames(entityNames: string[] | undefined): Set<string>;
}
